@@ -1,6 +1,5 @@
 # TYPE: 'exec' ----
 qryflow_exec_parser <- function(x, ...) {
-
   lines <- read_sql_lines(x)
 
   all_tags <- extract_all_tags(lines)
@@ -16,20 +15,16 @@ qryflow_exec_parser <- function(x, ...) {
   sql_txt <- collapse_sql_lines(lines[!is_tag_line(lines)])
 
   new_qryflow_chunk(type = "exec", name = name, sql = sql_txt, tags = tags)
-
 }
 
-qryflow_exec_handler <- function(chunk, con, ...) {
-
+qryflow_exec_handler <- function(con, chunk, ...) {
   result <- DBI::dbExecute(con, chunk$sql, ...)
 
   result
-
 }
 
 # TYPE: 'query' ----
 qryflow_query_parser <- function(x, ...) {
-
   lines <- read_sql_lines(x)
 
   all_tags <- extract_all_tags(lines)
@@ -45,14 +40,10 @@ qryflow_query_parser <- function(x, ...) {
   sql_txt <- collapse_sql_lines(lines[!is_tag_line(lines)])
 
   new_qryflow_chunk(type = "query", name = name, sql = sql_txt, tags = tags)
-
 }
 
-qryflow_query_handler <- function(chunk, con, ...) {
-
+qryflow_query_handler <- function(con, chunk, ...) {
   result <- DBI::dbGetQuery(con, chunk$sql, ...)
 
   result
-
 }
-
