@@ -4,7 +4,7 @@ test_that("qryflow() returns list", {
   on.exit(DBI::dbDisconnect(con), add = TRUE)
   path <- example_sql_path()
 
-  results <- qryflow(path, con)
+  results <- qryflow(con, path)
 
   expect_type(results, "list")
 })
@@ -14,7 +14,7 @@ test_that("When simplify=TRUE, qryflow() returns data.frame with 1 chunk", {
   on.exit(DBI::dbDisconnect(con), add = TRUE)
   path <- example_sql_path("get_mtcars.sql")
 
-  results <- qryflow(path, con)
+  results <- qryflow(con, path)
 
   expect_s3_class(results, "data.frame")
 })
@@ -26,7 +26,7 @@ test_that("qryflow_run() returns `qryflow_results`", {
   on.exit(DBI::dbDisconnect(con), add = TRUE)
   path <- example_sql_path("get_mtcars.sql")
 
-  results <- qryflow_run(path, con)
+  results <- qryflow_run(con, path)
 
   expect_s3_class(results, "qryflow_result")
 })
@@ -38,7 +38,7 @@ test_that("qryflow_results() returns list", {
   on.exit(DBI::dbDisconnect(con), add = TRUE)
   path <- example_sql_path("get_mtcars.sql")
 
-  obj <- qryflow_run(path, con)
+  obj <- qryflow_run(con, path)
   results <- qryflow_results(obj)
 
   expect_type(results, "list")
@@ -49,7 +49,7 @@ test_that("qryflow_results() returns data.frame when simplify=TRUE and 1 chunk",
   on.exit(DBI::dbDisconnect(con), add = TRUE)
   path <- example_sql_path("get_mtcars.sql")
 
-  obj <- qryflow_run(path, con)
+  obj <- qryflow_run(con, path)
   results <- qryflow_results(obj, simplify = TRUE)
 
   expect_s3_class(results, "data.frame")
